#!/bin/sh
#
# @(#) Fibranet NSP, SL
# Copyright (C) 2005-2009 by Jordi Sanfeliu <jordi@fibranet.cat>
# 	- Debian contribution by Uwe Heidrich <uweheidrich@hotmail.com>
# 	- Gentoo contribution by Matej Povazaj <ybdaba@gmail.com>
#	- Slackware contribution by Bogdan <bogdan@nimblex.net>
#
# Install shell-script for Monitorix
#

show_paths() {
	echo
	echo "The following is a list of the default paths where to install the Monitorix"
	echo "components:"
	echo
	echo "	1 - $SBIN"
	echo "	2 - $ETC"
	echo "	3 - $INIT"
	echo "	4 - $LIB"
	echo "	5 - $DOC"
	echo "	6 - $HTDOCS"
	echo "	7 - $CGIBIN"
	echo "	8 - $MAN"
}

OS=`uname -s`

echo
echo "Welcome to Monitorix v1.3.1 installation process."
echo

case $OS in
	Linux)
		echo "This install script has detected that this is a $OS operating system."
		echo
		OK=0
		while [ $OK -eq 0 ] ; do
		echo "Currently Monitorix supports only the following $OS distributions:"
		echo "	1 - RedHat/Fedora/CentOS"
		echo "	2 - Generic"
		echo "	3 - Debian"
		echo "	4 - Gentoo"
		echo "	5 - Slackware"
		echo
		echo -n "	Please select your option: "
		read distro
		case $distro in
			1)
				echo
				echo "Please don't use tar.gz files on RedHat/Fedora/CentOS distributions, they"
				echo "offer a better way to install packages".
				echo "Please, go to http://www.monitorix.org/ and download your RPM package."
				echo
				echo "To keep your system clean, this script won't continue."
				echo
				exit 0
				;;

			2)
				SBIN="/usr/local/sbin"
				ETC="/usr/local/etc"
				INIT="/usr/local/etc/rc.d"
				LIB="/usr/local/lib"
				DOC="/usr/local/share"
				HTDOCS="/usr/local/www/data"
				CGIBIN="/usr/local/www/cgi-bin"
				MAN="/usr/local/man/man5"
				PORTS="${OS}-Generic"
				show_paths
				OK=1
				;;
			3)
				SBIN="/usr/bin"
				ETC="/etc"
				INIT="/etc/init.d"
				LIB="/var/lib"
				DOC="/usr/share/doc"
				HTDOCS="/var/www"
				CGIBIN="/usr/lib/cgi-bin"
				MAN="/usr/share/man/man5"
				PORTS="${OS}-Debian"
				show_paths
				OK=1
				;;
			4)
				SBIN="/usr/sbin"
				ETC="/etc"
				INIT="/etc/init.d"
				LIB="/var/lib"
				DOC="/usr/share/doc"
				HTDOCS="/var/www/localhost/htdocs"
				CGIBIN="/var/www/localhost/cgi-bin"
				MAN="/usr/share/man/man5"
				PORTS="${OS}-Gentoo"
				show_paths
				OK=1
				;;
			5)
				SBIN="/usr/sbin"
				ETC="/etc"
				INIT="/etc/rc.d"
				LIB="/var/lib"
				DOC="/usr/share/doc"
				HTDOCS="/var/www/htdocs"
				CGIBIN="/var/www/cgi-bin"
				MAN="/usr/share/man/man5"
				PORTS="${OS}-Slack"
				show_paths
				OK=1
				;;
			*)
				echo "Bad option!. Try again please."
				echo
				;;
		esac
		done
		;;

	FreeBSD)
		echo "The install script has detected that this is a $OS operating system."
		SBIN="/usr/local/sbin"
		ETC="/usr/local/etc"
		INIT="/usr/local/etc/rc.d"
		LIB="/usr/local/lib"
		DOC="/usr/local/share"
		HTDOCS="/usr/local/www/data"
		CGIBIN="/usr/local/www/cgi-bin"
		MAN="/usr/local/man/man5"
		PORTS="$OS"
		show_paths
		;;

	*)
		echo
		echo "Sorry. Your operating system \"$OS\" is not supported right now."
		echo "Please contact to Jordi Sanfeliu <jordi@fibranet.cat> if you are interested"
		echo "to start the portability process together."
		echo
		exit 1
		;;

esac

echo
echo "Last chance to stop the installation."
OK=0
while [ $OK -eq 0 ] ; do
echo -n "Are you sure to install Monitorix on the paths shown? [y/n]: "
read sure
case $sure in
	[nN])
		echo
		echo "Aborting installation."
		exit 1
		;;

	[yY])
		echo
		echo "Starting installation."
		OK=1
		;;

	*)
		;;
esac
done

echo "Copying core script to $SBIN directory"
echo "monitorix.pl"
install -D -m 755 monitorix.pl $SBIN/monitorix.pl
if [ $? -gt 0 ] ; then
	echo
	echo "You don't have enough permissions to install Monitorix."
	echo "Please, execute this script as 'root' or use the command sudo:"
	echo "sudo ./install.sh"
	echo
	exit 1
fi
echo

echo "Copying configuration file to $ETC directory"
echo "monitorix.conf"
if [ -f $ETC/monitorix.conf ] ; then
	echo "backing up the previous monitorix.conf file."
	mv -f $ETC/monitorix.conf $ETC/monitorix.conf.bak
fi
install -D -m 644 monitorix.conf $ETC/monitorix.conf
sed 's/our \$OSTYPE = \"Linux-RHFC\"/our \$OSTYPE = \"'$PORTS'\"/' monitorix.conf > $ETC/monitorix.conf
echo

echo "Copying init script to $INIT directory"
echo "ports/${PORTS}/monitorix.init"
install -D -m 755 ports/${PORTS}/monitorix.init $INIT/monitorix
echo

echo "Copying report files to $LIB directory"
echo "reports/"
install -m 755 -d reports $LIB/monitorix/reports
cp -r reports $LIB/monitorix/
mkdir $LIB/monitorix/usage
echo

echo "Copying documentation files to $DOC directory"
objs="Changes COPYING monitorix-apache.conf monitorix.spec README README.Debian README.nginx README.Slackware TODO"
echo $objs
for file in $objs ; do
	install -D -m 644 $file $DOC/monitorix/$file
done
echo

echo "Copying html files to $HTDOCS directory"
objs="envelope.png logo_bot_black.png logo_bot_white.png logo_top.jpg"
echo $objs
for file in $objs ; do
	install -D -m 644 $file $HTDOCS/monitorix/$file
done
mkdir -p $HTDOCS/monitorix/imgs
chmod 777 $HTDOCS/monitorix/imgs
echo

echo "Copying cgi-bin files to $CGIBIN directory"
echo "monitorix.cgi"
install -D -m 755 monitorix.cgi $CGIBIN/monitorix.cgi
echo

echo "Copying man pages to $MAN directory"
echo "monitorix.conf.5"
gzip -9 man/man5/monitorix.conf.5
install -D -m 644 man/man5/monitorix.conf.5.gz $MAN/monitorix.conf.5.gz
echo

if [ $distro = "5" ] ; then	# required for Slackware and maybe others
	mkdir /etc/cron.d 2>/dev/null
	mkdir /var/lib/monitorix 2>/dev/null
fi

echo "---------------------------------------------------------------------"
echo
echo "Installation succesfully finished."
echo "Now start Monitorix executing the init script:"
echo
echo "service monitorix start"
echo "or"
echo "$INIT/monitorix.sh [start|stop|status]"
echo
echo "and finally go to http://localhost/monitorix/ to start seeing the results."
echo
echo "NOTE: As a crond-based application, the root user will receive emails"
echo "about Monitorix execution errors. Please check the root email.".
echo
exit 0

